@@ -26,6 +26,7 @@
 import os, traceback
 import json
 import yaml
+import cPiclke
 from . import jsoncall
 import cherrypy
 from . import base
@@ -430,7 +431,7 @@ class Server:
             return '''
 <h1>Personis</h1>
 Looks like you're coming into the service entrance with a browser, which is not how this works. Ask someme about 'Mneme', or perhaps you're looking for <a href="/list_apps">your apps</a>.
-<br/>If you're an administrator, you might want to try <a href="/list_clients">the admin page</a>, or the <a href="http://packages.python.org/personis/">the docs</a>.
+<br/>If you're an administrator, you might want to try <a href="/list_clients">the admin page</a>, or the <a href="http://personis.readthedocs.org/en/latest/">the docs</a>.
 <br/>Source at <a href="https://github.com/jbu/personis">github</a>.
 '''
         if access_token not in access_tokens:
@@ -635,8 +636,6 @@ def runServer(modeldir, config, admins, clients, tokens, loglevel=logging.INFO,
         try:
             cherrypy.config.update(os.path.expanduser(config))
             cherrypy.tree.mount(Server(modeldir, admins, clients, tokens, client_secrets), '/', config=config)
-            #cherrypy.server.ssl_certificate = "server.crt"
-            #cherrypy.server.ssl_private_key = "server.key" 
             cherrypy.engine.start()
             if not exit_queue:
                 cherrypy.engine.block()
