@@ -1,4 +1,4 @@
 #sudo easy_install sphinx-pypi-upload
-python setup.py build_sphinx register sdist bdist upload # upload_sphinx
+python setup.py build_sphinx register sdist upload # upload_sphinx
 #python setup.py build_sphinx sdist bdist # upload_sphinx
 
